# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from modeltranslation.admin import TabbedTranslationAdmin, TranslationAdmin


class CustomMinTabbedTranslationAdmin(TranslationAdmin):
    class Media:
        js = (
            'modeltranslation-grappelli/js/force_jquery.js',
            'modeltranslation-grappelli/js/tabbed_translation_fields.js',
        )
        css = {
            'all': (
                'modeltranslation-grappelli/css/tabbed_translation_fields.css',
                'modeltranslation-grappelli/css/custom_tabbed_translation_fields.css'
            ),
        }


class MinTabbedTranslationAdmin(TabbedTranslationAdmin):
    class Media:
        css = {
            'all': (
                'modeltranslation-grappelli/css/tabbed_translation_fields.css',
                'modeltranslation-grappelli/css/custom_tabbed_translation_fields.css'
            ),
        }


# -*- coding: utf-8 -*-
from setuptools import setup


README = open('README.md').read()


setup(
    name='modeltranslation-grappelli',
    version='3.0.0',
    author='Konstantin Liuterovich',
    author_email='constantin3627@gmail.com',

    description='django-modeltranslation with support grappelli.',
    long_description=README,
    url='https://github.com/Brogency/modeltranslation-grappelli',
    license='BSD',

    packages=[
        'modeltranslation_grappelli',
        'modeltranslation_grappelli.admin',
    ],
    package_data={
        'modeltranslation_grappelli': ['static/modeltranslation-grappelli/css/*.css',
                                       'static/modeltranslation-grappelli/js/*.js']},
    install_requires=[
        'django-modeltranslation>=0.9',
    ],

    zip_safe=False,
    include_package_data=True
)